# event-tracking-service

ETS is a loosely coupled graph service, able to illustrate
chains of events when all events in the chain properly exist.

It can also be used to see the impact of an automation event.

# bootstrap

    ./uranium

# running the service

    ./uranium dev

# running tests

    ./uranium test
